@@ -14,7 +14,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import cookielib
 import shlex
 import socket
 import subprocess
@@ -23,14 +22,14 @@ import time
 
 from oslo_log import log as logging
 import six
+from six.moves import http_cookiejar
 from six.moves.urllib import error
 from six.moves.urllib import request as urllib2
 from tempest.common import waiters
 from tempest import config
 from tempest import exceptions
+from tempest.lib.common.utils import test_utils
 from tempest.lib import exceptions as lib_exc
-from tempest.scenario import manager
-from tempest.scenario import network_resources as net_resources
 from tempest import test
 
 from neutron_lbaas._i18n import _
@@ -39,6 +38,7 @@ from neutron_lbaas.tests.tempest.v2.clients import listeners_client
 from neutron_lbaas.tests.tempest.v2.clients import load_balancers_client
 from neutron_lbaas.tests.tempest.v2.clients import members_client
 from neutron_lbaas.tests.tempest.v2.clients import pools_client
+from neutron_lbaas.tests.tempest.v2.scenario import manager
 
 config = config.CONF
 
@@ -118,17 +118,19 @@ class BaseTestCase(manager.NetworkScenarioTest):
         The configured private network and associated subnet is used as a
         fallback in absence of tenant networking.
         """
+        tenant_id = self.networks_client.tenant_id
         try:
-            tenant_net = self._list_networks(tenant_id=self.tenant_id)[0]
+            tenant_net = self.admin_manager.networks_client.list_networks(
+                tenant_id=tenant_id)['networks'][0]
         except IndexError:
             tenant_net = None
 
         if tenant_net:
-            tenant_subnet = self._list_subnets(tenant_id=self.tenant_id)[0]
-            self.subnet = net_resources.DeletableSubnet(
-                subnets_client=self.subnets_client,
-                routers_client=self.routers_client,
-                **tenant_subnet)
+            self.subnet = self.admin_manager.subnets_client.list_subnets(
+                tenant_id=tenant_id)['subnets'][0]
+            self.addCleanup(test_utils.call_and_ignore_notfound_exc,
+                            self.networks_client.delete_network,
+                            self.subnet['id'])
             self.network = tenant_net
         else:
             self.network = self._get_network_by_name(
@@ -137,12 +139,13 @@ class BaseTestCase(manager.NetworkScenarioTest):
             # with the fixed network is the one we want.  In the future, we
             # should instead pull a subnet id from config, which is set by
             # devstack/admin/etc.
-            subnet = self._list_subnets(network_id=self.network['id'])[0]
-            self.subnet = net_resources.AttributeDict(subnet)
+            subnet = self.admin_manager.subnets_client.list_subnets(
+                network_id=self.network['id'])['subnets'][0]
+            self.subnet = subnet
 
     def _create_security_group_for_test(self):
         self.security_group = self._create_security_group(
-            tenant_id=self.tenant_id)
+            tenant_id=self.networks_client.tenant_id)
         self._create_security_group_rules_for_port(self.port1)
         self._create_security_group_rules_for_port(self.port2)
 
@@ -155,12 +158,13 @@ class BaseTestCase(manager.NetworkScenarioTest):
         }
         self._create_security_group_rule(
             secgroup=self.security_group,
-            tenant_id=self.tenant_id,
+            tenant_id=self.networks_client.tenant_id,
             **rule)
 
     def _ipv6_subnet(self, address6_mode):
-        router = self._get_router(tenant_id=self.tenant_id)
-        self.network = self._create_network(tenant_id=self.tenant_id)
+        tenant_id = self.networks_client.tenant_id
+        router = self._get_router(tenant_id=tenant_id)
+        self.network = self._create_network(tenant_id=tenant_id)
         self.subnet = self._create_subnet(network=self.network,
                                           namestart='sub6',
                                           ip_version=6,
@@ -192,8 +196,8 @@ class BaseTestCase(manager.NetworkScenarioTest):
             public_network_id = config.network.public_network_id
             floating_ip = self.create_floating_ip(
                 server, public_network_id)
-            self.floating_ips[floating_ip] = server
-            self.server_ips[server['id']] = floating_ip.floating_ip_address
+            self.floating_ips[floating_ip['id']] = server
+            self.server_ips[server['id']] = floating_ip['floating_ip_address']
         else:
             self.server_ips[server['id']] =\
                 server['addresses'][net_name][0]['addr']
@@ -281,11 +285,12 @@ class BaseTestCase(manager.NetworkScenarioTest):
                                       'script': 'script2'}
                 ssh_client.exec_command(cmd)
 
-    def _create_listener(self, load_balancer_id):
+    def _create_listener(self, load_balancer_id, port=80, protocol='HTTP',
+                         **kwargs):
         """Create a listener with HTTP protocol listening on port 80."""
         self.listener = self.listeners_client.create_listener(
             loadbalancer_id=load_balancer_id,
-            protocol='HTTP', protocol_port=80)
+            protocol=protocol, protocol_port=port, **kwargs)
         self.assertTrue(self.listener)
         self.addCleanup(self._cleanup_listener, self.listener.get('id'),
                         load_balancer_id=load_balancer_id)
@@ -320,23 +325,25 @@ class BaseTestCase(manager.NetworkScenarioTest):
         return self.pool
 
     def _cleanup_load_balancer(self, load_balancer_id):
-        self.delete_wrapper(self.load_balancers_client.delete_load_balancer,
-                            load_balancer_id)
+        test_utils.call_and_ignore_notfound_exc(
+            self.load_balancers_client.delete_load_balancer, load_balancer_id)
         self._wait_for_load_balancer_status(load_balancer_id, delete=True)
 
     def _cleanup_listener(self, listener_id, load_balancer_id=None):
-        self.delete_wrapper(self.listeners_client.delete_listener, listener_id)
+        test_utils.call_and_ignore_notfound_exc(
+            self.listeners_client.delete_listener, listener_id)
         if load_balancer_id:
             self._wait_for_load_balancer_status(load_balancer_id)
 
     def _cleanup_pool(self, pool_id, load_balancer_id=None):
-        self.delete_wrapper(self.pools_client.delete_pool, pool_id)
+        test_utils.call_and_ignore_notfound_exc(
+            self.pools_client.delete_pool, pool_id)
         if load_balancer_id:
             self._wait_for_load_balancer_status(load_balancer_id)
 
     def _cleanup_health_monitor(self, hm_id, load_balancer_id=None):
-        self.delete_wrapper(self.health_monitors_client.delete_health_monitor,
-                            hm_id)
+        test_utils.call_and_ignore_notfound_exc(
+            self.health_monitors_client.delete_health_monitor, hm_id)
         if load_balancer_id:
             self._wait_for_load_balancer_status(load_balancer_id)
 
@@ -375,16 +382,17 @@ class BaseTestCase(manager.NetworkScenarioTest):
 
     def _assign_floating_ip_to_lb_vip(self, lb):
         public_network_id = config.network.public_network_id
-        port_id = lb.vip_port_id
+        port_id = lb['vip_port_id']
         floating_ip = self.create_floating_ip(lb, public_network_id,
                                               port_id=port_id)
-        self.floating_ips.setdefault(lb.id, [])
-        self.floating_ips[lb.id].append(floating_ip)
+        self.floating_ips.setdefault(lb['id'], [])
+        self.floating_ips[lb['id']].append(floating_ip)
         # Check for floating ip status before you check load-balancer
         self.check_floating_ip_status(floating_ip, "ACTIVE")
 
     def _create_load_balancer(self, ip_version=4, persistence_type=None):
-        self.create_lb_kwargs = {'tenant_id': self.tenant_id,
+        tenant_id = self.networks_client.tenant_id
+        self.create_lb_kwargs = {'tenant_id': tenant_id,
                                  'vip_subnet_id': self.subnet['id']}
         self.load_balancer = self.load_balancers_client.create_load_balancer(
             **self.create_lb_kwargs)
@@ -410,10 +418,9 @@ class BaseTestCase(manager.NetworkScenarioTest):
         if ip_version == 4:
             if (config.network.public_network_id and not
                     config.network.project_networks_reachable):
-                load_balancer = net_resources.AttributeDict(self.load_balancer)
-                self._assign_floating_ip_to_lb_vip(load_balancer)
+                self._assign_floating_ip_to_lb_vip(self.load_balancer)
                 self.vip_ip = self.floating_ips[
-                    load_balancer.id][0]['floating_ip_address']
+                    self.load_balancer['id']][0]['floating_ip_address']
 
         # Currently the ovs-agent is not enforcing security groups on the
         # vip port - see https://bugs.launchpad.net/neutron/+bug/1163569
@@ -421,7 +428,7 @@ class BaseTestCase(manager.NetworkScenarioTest):
         # security group with a rule that allows tcp port 80 to the vip port.
         self.ports_client.update_port(
             self.load_balancer.get('vip_port_id'),
-            security_groups=[self.security_group.id])
+            security_groups=[self.security_group['id']])
 
     def _wait_for_load_balancer_status(self, load_balancer_id,
                                        provisioning_status='ACTIVE',
@@ -434,11 +441,11 @@ class BaseTestCase(manager.NetworkScenarioTest):
             try:
                 lb = self.load_balancers_client.get_load_balancer(
                     load_balancer_id)
-            except lib_exc.NotFound as e:
+            except lib_exc.NotFound:
                 if delete:
                     return
                 else:
-                    raise e
+                    raise
             if (lb.get('provisioning_status') == provisioning_status and
                     lb.get('operating_status') == operating_status):
                 break
@@ -485,13 +492,13 @@ class BaseTestCase(manager.NetworkScenarioTest):
                   pool_id=pool_id,
                   type=sp_type))
 
-    def _check_load_balancing(self):
+    def _check_load_balancing(self, port=80):
         """
         1. Send NUM requests on the floating ip associated with the VIP
         2. Check that the requests are shared between the two servers
         """
 
-        self._check_connection(self.vip_ip)
+        self._check_connection(self.vip_ip, port=port)
         counters = self._send_requests(self.vip_ip, ["server1", "server2"])
         for member, counter in six.iteritems(counters):
             self.assertGreater(counter, 0, 'Member %s never balanced' % member)
@@ -508,11 +515,12 @@ class BaseTestCase(manager.NetworkScenarioTest):
                 return False
             except error.HTTPError:
                 return False
-        timeout = config.validation .ping_timeout
+        timeout = config.validation.ping_timeout
         start = time.time()
         while not try_connect(check_ip, port):
             if (time.time() - start) > timeout:
-                message = "Timed out trying to connect to %s" % check_ip
+                message = ("Timed out trying to connect to {0}:{1} after "
+                           "{2} seconds".format(check_ip, port, timeout))
                 raise exceptions.TimeoutException(message)
 
     def _send_requests(self, vip_ip, servers):
@@ -566,7 +574,7 @@ class BaseTestCase(manager.NetworkScenarioTest):
                                          cookie_name=None):
         """Update a pool with new session persistence type and cookie name."""
 
-        update_data = {}
+        update_data = {'session_persistence': None}
         if persistence_type:
             update_data = {"session_persistence": {
                 "type": persistence_type}}
@@ -588,7 +596,7 @@ class BaseTestCase(manager.NetworkScenarioTest):
         """Check cookie persistence types by injecting cookies in requests."""
 
         # Send first request and get cookie from the server's response
-        cj = cookielib.CookieJar()
+        cj = http_cookiejar.CookieJar()
         opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cj))
         opener.open("http://{0}/".format(self.vip_ip))
         resp = []
